import {
  Image,
  Cell,
  CellGroup,
  Tag,
  Button,
  Stepper,
  Icon,
  Popup,
  showConfirmDialog,
  showToast
} from 'vant';
import { computed, defineComponent, onMounted, reactive } from 'vue';
import styles from './index.module.less';
import MSticky from '@/components/m-sticky';
import MVideo from '@/components/m-video';
import { useRoute, useRouter } from 'vue-router';
import { useStudentRegisterStore } from '@/store/modules/student-register-store';
import request from '@/helpers/request';
import { browser, moneyFormat } from '@/helpers/utils';
import deepClone from '@/helpers/deep-clone';
import OWxTip from '@/components/m-wx-tip';
import MDialog from '@/components/m-dialog';
import f1 from './images/new/f-1.png';
import f2 from './images/new/f-2.png';
import f3 from './images/new/f-3.png';
import iconTip2 from './images/new/icon-tip2.png';
import functionBg from './images/new/function-bg.png';
import giftTip from './images/new/gift-tip.png';

export default defineComponent({
  name: 'student-register',
  setup() {
    const route = useRoute();
    const studentRegisterStore = useStudentRegisterStore();
    const router = useRouter();
    // 初始化学校编号
    studentRegisterStore.setShoolId(route.query.sId as any);
    const forms = reactive({
      schoolId: route.query.sId as any,
      paymentType: '', // 支付类型
      popupShow: false,
      details: [] as any[],
      schoolType: '', // 学校类型
      gradeYear: '', // 学制
      bugGoods: false, // 是否购买AI
      registerType: '', // 报名类型
      detailVip: {} as any,
      giftVipDay: 0, // 赠送天数
      submitLoading: false,
      showMore: true,
      showTips: false,
      showButton: false,
      showMessage: '请使用微信打开'
    });

    const getRegisterGoods = async () => {
      try {
        const { data } = await request.get(
          '/edu-app/open/userOrder/registerGoods/' + forms.schoolId,
          {
            noAuthorization: true // 是否请求接口的时候添加toekn
          }
        );
        // 默认选中商品
        studentRegisterStore.setVip(data.details || []);
        forms.details = deepClone(data.details || []);
        if (forms.details.length > 0) {
          forms.detailVip = forms.details[0];
          forms.giftVipDay = forms.details[0].membershipDays;
        }
        forms.bugGoods = data.bugGoods;
        forms.schoolType = data.schoolType;
        forms.gradeYear = data.gradeYear;
        forms.registerType = data.registerType;
        if (browser().weixin) {
          if (data.registerType !== 'BUG_GOODS' || data.schoolStatus === 0) {
            forms.showTips = true;
            forms.showMessage = '二维码已经失效，详情请咨询学校老师';
            forms.showButton = false;
          }
        } else {
          forms.showTips = true;
        }
      } catch {}
    };

    // 计算金额
    const calcPrice = computed(() => {
      let amount: number = 0; //现价
      let originAmount: number = 0; // 原价
      const vipList: any[] = studentRegisterStore.getVip;
      vipList.forEach((vip: any) => {
        amount += Number(vip.currentPrice);
        originAmount += Number(vip.originalPrice);
      });

      // const goodsList: any[] = studentRegisterStore.getGoods;
      // goodsList.forEach((good: any) => {
      //   amount += Number(good.price) * good.quantity;
      //   originAmount += Number(good.originalPrice) * good.quantity;
      // });
      return {
        amount,
        originAmount
      };
    });

    // 删除商品
    // const onGoodsRemove = (item: any) => {
    //   showConfirmDialog({
    //     message: '是否删除该商品',
    //     confirmButtonColor: '#FF8633'
    //   }).then(() => {
    //     studentRegisterStore.deleteGoods(item.productSkuId);
    //   });
    // };

    // 登记成功之后购买
    const onRegisterSubmit = async () => {
      try {
        forms.submitLoading = true;

        // 检测token是否失效
        // const Authorization = storage.get(ACCESS_TOKEN) || '';
        // const authInfo = await request.post('/edu-app/open/user/verification', {
        //   noAuthorization: true,
        //   data: { token: Authorization }
        // });
        // // 判断当前token是否失效
        // if (!authInfo.data) {
        //   storage.remove(ACCESS_TOKEN);
        //   studentRegisterStore.deleteToken();
        //   forms.popupRegister = true;
        //   return;
        // }

        // // 请求是否有待支付订单，如果有则自动关闭
        // const status = await paymentOrderUnpaid();
        // if (status) return;
        // const schoolInfo = await request.get(
        //   '/edu-app/userPaymentOrder/registerStatus/' + forms.schoolId
        // );
        // const vipList = studentRegisterStore.getVip;

        // if (schoolInfo.data.hasBuyCourse && vipList.length > 0) {
        //   // setTimeout(() => {
        //   //   showToast('您已购买乐器AI学练工具，请勿重复购买');
        //   // }, 100);
        //   forms.dialogConfirmStatus = true;
        //   return;
        // }
        // await paymentContinue();

        router.push({
          path: '/student-register-form',
          query: {
            schoolId: forms.schoolId
          }
        });
      } finally {
        forms.submitLoading = false;
      }
    };

    onMounted(async () => {
      try {
        getRegisterGoods();
      } catch {}
    });

    return () => (
      <div class={styles['student-register']}>
        <div class={styles.studentRegisterContainer}>
          <div class={styles.studentSection}>
            <div class={styles.title1}></div>

            <p class={styles.content}>
              提供在乐器学练中的AI智能学练工具、数字化乐谱与课件，解决学生不会练习、家长无法辅导的乐器学练痛点，学生可实现自主学练，家长即时全面了解学练情况。
            </p>
          </div>
          <div class={[styles.studentSection, styles.truns]}>
            <div class={styles.trunList}>
              <div class={styles.trunItem}>
                <img src={f1} />
                <p>
                  随身云教练
                  <br />
                  无需请老师
                </p>
              </div>
              <div class={styles.trunItem}>
                <img src={f2} />
                <p>
                  简单易操作
                  <br />
                  学生都会练
                </p>
              </div>
              <div class={styles.trunItem}>
                <img src={f3} />
                <p>
                  练习可测评
                  <br />
                  家长可省心
                </p>
              </div>
            </div>

            <div class={styles.tipInfo}>
              <img src={iconTip2} />
            </div>
          </div>

          {/* <div class={styles.videoGroup}>
            <MVideo
              class={styles.videoB}
              src={'https://oss.dayaedu.com/daya/202105/SWmqmvW.mp4'}
            />
          </div> */}

          <div class={styles.studentSection}>
            <div class={styles.title2}></div>

            <div class={styles.functionGroup}>
              <img src={functionBg} />
            </div>
          </div>

          {forms.giftVipDay > 0 && (
            <div class={[styles.studentSection, styles.memberGroup]}>
              <p>
                现在购买赠送会员有效期<span>{forms.giftVipDay || 0}</span>天
              </p>
            </div>
          )}

          <MSticky position="bottom">
            <div class={styles.paymentContainer}>
              <div class={styles.payemntPrice}>
                <img src={giftTip} class={styles.giftTip} />
                <div>
                  <span class={styles.needPrice}>
                    <i style="font-style: normal">¥ </i>
                    <span>{moneyFormat(calcPrice.value.amount)}</span>
                    <i style="font-style: normal">/年</i>
                  </span>
                  {calcPrice.value.originAmount > calcPrice.value.amount ? (
                    <del class={styles.allPrice}>
                      ¥ {moneyFormat(calcPrice.value.originAmount)}
                    </del>
                  ) : (
                    ''
                  )}
                </div>
              </div>
              <div
                class={styles.paymentBtn}
                onClick={() => {
                  // const vipList = studentRegisterStore.getVip;
                  // const goodsList = studentRegisterStore.getGoods;
                  // if (vipList.length <= 0 && goodsList.length <= 0) {
                  //   setTimeout(() => {
                  //     showToast('请选择需要购买的商品');
                  //   }, 100);
                  //   return;
                  // }
                  onRegisterSubmit();
                }}>
                <Button
                  round
                  disabled={forms.submitLoading}
                  loading={forms.submitLoading}>
                  下一步
                </Button>
              </div>
            </div>
          </MSticky>
        </div>

        {/* <Popup v-model:show={forms.popupShow} class={styles.videoPopup}>
          {forms.popupShow && (
            <MVideo src={'https://oss.dayaedu.com/daya/202105/SWmqmvW.mp4'} />
          )}
        </Popup> */}

        {/* 是否在微信中打开 */}
        <OWxTip
          show={forms.showTips}
          message={forms.showMessage}
          showButton={forms.showButton}
          buttonText="刷新"
          onConfirm={() => window.location.reload()}
        />
      </div>
    );
  }
});
